@@ -1,6 +1,4 @@
-"""
-SatNOGS Client module main function
-"""
+"""SatNOGS Client module main function"""
 from __future__ import absolute_import, division, print_function
 
 import sys
