@@ -52,12 +52,11 @@ def spawn_observer(**kwargs):
     }
 
     LOGGER.debug('Observer args: %s', setup_kwargs)
-    setup = observer.setup(**setup_kwargs)
 
-    if setup:
+    if observer.setup(**setup_kwargs):
         LOGGER.info('Spawning observer worker.')
         timeout_timedelta = end - datetime.now(pytz.utc)
-        if timeout_timedelta.total_seconds() == 0:
+        if timeout_timedelta.total_seconds() <= 0:
             timeout_timedelta = timedelta()
         if not OBSERVER_LOCK.acquire(timeout=timeout_timedelta.total_seconds()):
             LOGGER.error('Observer job lock acquiring timed out.')
@@ -71,7 +70,7 @@ def spawn_observer(**kwargs):
 def keep_or_remove_file(filename):
     # If set, move uploaded file to `SATNOGS_COMPLETE_OUTPUT_PATH`,
     # otherwise delete it
-    if settings.SATNOGS_COMPLETE_OUTPUT_PATH != '':
+    if settings.SATNOGS_COMPLETE_OUTPUT_PATH:
         os.rename(os.path.join(settings.SATNOGS_OUTPUT_PATH, filename),
                   os.path.join(settings.SATNOGS_COMPLETE_OUTPUT_PATH, filename))
     else:
@@ -85,26 +84,38 @@ def post_data():
     for fil in next(os.walk(settings.SATNOGS_OUTPUT_PATH))[2]:
         file_path = os.path.join(*[settings.SATNOGS_OUTPUT_PATH, fil])
         if (fil.startswith('receiving_satnogs') or fil.startswith('receiving_waterfall')
-                or fil.startswith('receiving_data') or os.stat(file_path).st_size == 0):
+                or fil.startswith('receiving_data') or not os.stat(file_path).st_size):
             continue
         if fil.startswith('satnogs'):
+            # This file is an audio file
             if not settings.SATNOGS_UPLOAD_AUDIO_FILES:
                 keep_or_remove_file(fil)
                 continue
             observation = {'payload': open(file_path, 'rb')}
         elif fil.startswith('waterfall'):
+            # This file is a waterfall image
             if not settings.SATNOGS_UPLOAD_WATERFALL_FILES:
                 keep_or_remove_file(fil)
                 continue
             observation = {'waterfall': open(file_path, 'rb')}
         elif fil.startswith('data'):
+            # This file is a data frame
+            # Check if it is serialized using json OR raw data
             try:
-                with open(file_path, 'r') as json_string:
+                with open(file_path, 'r', encoding='utf-8') as json_string:
                     data = json.load(json_string)
+                if not isinstance(data, dict) or 'pdu' not in data.keys():
+                    # File can accidentally be parsed as json, but is missing the expected fields.
+                    # Thus we assume it is a raw data frame
+                    raise ValueError
+
+                # This file is a json-encoded data frame
                 observation = {'demoddata': (fil, base64.b64decode(data['pdu']))}
             except ValueError:
+                # This file is a raw data frame
                 observation = {'demoddata': open(file_path, 'rb')}
         else:
+            # This file is of unknown type
             LOGGER.debug('Ignore file: %s', fil)
             continue
         if '_' not in fil:
@@ -182,11 +193,10 @@ def get_jobs():
                                 headers=headers,
                                 verify=settings.SATNOGS_VERIFY_SSL,
                                 timeout=45)
+        response.raise_for_status()
     except (requests.ConnectionError, requests.Timeout, requests.TooManyRedirects):
         LOGGER.exception('An error occurred trying to GET observation jobs from network')
-
-    try:
-        response.raise_for_status()
+        return
     except requests.exceptions.HTTPError as http_error:
         LOGGER.error(http_error)
         return
