@@ -1,6 +1,4 @@
-"""
-SatNOGS Client settings file
-"""
+"""SatNOGS Client settings file"""
 from __future__ import absolute_import, division, print_function
 
 import os
@@ -43,15 +41,16 @@ SATNOGS_OUTPUT_PATH = environ.get('SATNOGS_OUTPUT_PATH', '/tmp/.satnogs/data')
 SATNOGS_COMPLETE_OUTPUT_PATH = environ.get('SATNOGS_COMPLETE_OUTPUT_PATH', '')
 SATNOGS_INCOMPLETE_OUTPUT_PATH = environ.get('SATNOGS_INCOMPLETE_OUTPUT_PATH',
                                              '/tmp/.satnogs/data/incomplete')
+SATNOGS_ARTIFACTS_OUTPUT_PATH = environ.get('SATNOGS_ARTIFACTS_OUTPUT_PATH',
+                                            '/tmp/.satnogs/artifacts')
 
-for p in [
-        SATNOGS_APP_PATH, SATNOGS_OUTPUT_PATH, SATNOGS_COMPLETE_OUTPUT_PATH,
-        SATNOGS_INCOMPLETE_OUTPUT_PATH
-]:
-    if p != '' and not os.path.exists(p):
+for p in (SATNOGS_APP_PATH, SATNOGS_OUTPUT_PATH, SATNOGS_COMPLETE_OUTPUT_PATH,
+          SATNOGS_INCOMPLETE_OUTPUT_PATH):
+    if p and not os.path.exists(p):
         os.mkdir(p)
 
 SATNOGS_REMOVE_RAW_FILES = bool(strtobool(environ.get('SATNOGS_REMOVE_RAW_FILES', 'True')))
+SATNOGS_KEEP_ARTIFACTS = bool(strtobool(environ.get('SATNOGS_KEEP_ARTIFACTS', 'False')))
 
 SATNOGS_VERIFY_SSL = bool(strtobool(environ.get('SATNOGS_VERIFY_SSL', 'True')))
 
@@ -68,6 +67,7 @@ SATNOGS_NETWORK_API_TIMEOUT = 1800  # In seconds
 GNURADIO_UDP_PORT = 16886
 GNURADIO_IP = '127.0.0.1'
 
+SATNOGS_ROT_ENABLED = bool(strtobool(environ.get('SATNOGS_ROT_ENABLED', 'True')))
 SATNOGS_ROT_MODEL = environ.get('SATNOGS_ROT_MODEL', 'ROT_MODEL_DUMMY')
 SATNOGS_ROT_BAUD = int(environ.get('SATNOGS_ROT_BAUD', 19200))
 SATNOGS_ROT_PORT = environ.get('SATNOGS_ROT_PORT', '/dev/ttyUSB0')
@@ -136,8 +136,7 @@ REQUIRED_VARIABLES = [
 
 
 def validate(logger):
-    """
-    Validate the provided settings:
+    """Validate the provided settings:
     - Check for the existance of all required variables
     - Validate format of the provided value for some required variables
 
@@ -172,7 +171,7 @@ def validate(logger):
         logger.error('SATNOGS_STATION_LON not configured')
         settings_valid = False
 
-    if SATNOGS_STATION_ELEV is None and SATNOGS_GPSD_CLIENT_ENABLED is False:
+    if not (SATNOGS_STATION_ELEV or SATNOGS_GPSD_CLIENT_ENABLED):
         logger.error('SATNOGS_STATION_ELEV not configured')
         settings_valid = False
 
