@@ -14,17 +14,15 @@ SCALE_IN_STDS = 8.0
 
 
 class EmptyArrayError(Exception):
-    """
-    Empty data array exception
-    """
+    """Empty data array exception"""
 
 
 def _read_waterfall(datafile_path):
-    """
-    Read waterfall data file
+    """Read waterfall data file
 
     :param datafile_path: Path to data file
     :type datafile_path: str
+    :raises EmptyArrayError: Empty waterfall data
     :return: Waterfall data
     :rtype: dict
     """
@@ -42,7 +40,7 @@ def _read_waterfall(datafile_path):
     }
     data_dtypes = np.dtype([('tabs', 'int64'), ('spec', 'float32', (waterfall['nchan'], ))])
     waterfall['data'] = np.fromfile(datafile, dtype=data_dtypes)
-    if waterfall['data'].size == 0:
+    if not waterfall['data'].size:
         raise EmptyArrayError
 
     datafile.close()
@@ -51,8 +49,7 @@ def _read_waterfall(datafile_path):
 
 
 def _compress_waterfall(waterfall):
-    """
-    Compress spectra of waterfall
+    """Compress spectra of waterfall
 
     :param waterfall: Watefall data
     :type waterfall: dict
@@ -69,8 +66,7 @@ def _compress_waterfall(waterfall):
 
 
 def _get_waterfall(datafile_path):
-    """
-    Get waterfall data
+    """Get waterfall data
 
     :param datafile_path: Path to data file
     :type datafile_path: str_array
@@ -92,26 +88,25 @@ def _get_waterfall(datafile_path):
 
 
 class Waterfall():  # pylint: disable=R0903
-    """
-    Parse waterfall data file
+    """Parse waterfall data file
 
     :param datafile_path: Path to data file
     :type datafile_path: str_array
     """
+
     def __init__(self, datafile_path):
-        """
-        Class constructor
-        """
+        """Class constructor"""
         self.data = _get_waterfall(datafile_path)
 
     def plot(self, figure_path, vmin=None, vmax=None):
-        """
-        Plot waterfall into a figure
+        """Plot waterfall into a figure
 
         :param figure_path: Path of figure file to save
         :type figure_path: str
-        :param value_range: Minimum and maximum value range
-        :type value_range: tuple
+        :param vmin: Minimum value range
+        :type vmin: int
+        :param vmax: Maximum value range
+        :type vmax: int
         """
         tmin = np.min(self.data['data']['tabs'] / 1000000.0)
         tmax = np.max(self.data['data']['tabs'] / 1000000.0)
